PRs are welcome.

In terms of style and tooling, we mostly follow the Trio contributing guide:
    https://trio.readthedocs.io/en/latest/contributing.html

In terms of project governance, though, this is currently mostly a
personal project; contributors will not automatically get commit bits and oremanj
reserves the right to make unreviewed PRs.
